==> jc-1.4.0.tar.gz: gnu/regexp/RETokenOneOf.h <==
// final class gnu.regexp.RETokenOneOf

// class file dependencies
// @dep_class 3c97b6b42ac22db4 gnu_regexp_REToken
// @dep_class d6d93778273344e gnu_regexp_RETokenOneOf
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_regexp_REToken

#include "gnu/regexp/REToken.h"

#ifndef _JC_gnu_regexp_RETokenOneOf_H_
#define _JC_gnu_regexp_RETokenOneOf_H_

// Forward structure declarations
struct _jc_gnu_regexp_CharIndexed$object;
struct _jc_gnu_regexp_REMatch$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_StringBuffer$object;
struct _jc_java_util_Vector$object;

// Typedefs
typedef struct _jc_gnu_regexp_RETokenOneOf$sub_refs	_jc_gnu_regexp_RETokenOneOf$sub_refs;
typedef struct _jc_gnu_regexp_RETokenOneOf$sub_nonrefs	_jc_gnu_regexp_RETokenOneOf$sub_nonrefs;
typedef struct _jc_gnu_regexp_RETokenOneOf$refs	_jc_gnu_regexp_RETokenOneOf$refs;
typedef struct _jc_gnu_regexp_RETokenOneOf$nonrefs	_jc_gnu_regexp_RETokenOneOf$nonrefs;
typedef struct _jc_gnu_regexp_RETokenOneOf$object	_jc_gnu_regexp_RETokenOneOf$object;

typedef const struct _jc_gnu_regexp_RETokenOneOf$vmethods	_jc_gnu_regexp_RETokenOneOf$vmethods;
typedef const struct _jc_gnu_regexp_RETokenOneOf$vtable	_jc_gnu_regexp_RETokenOneOf$vtable;
typedef const struct _jc_gnu_regexp_RETokenOneOf$vtype	_jc_gnu_regexp_RETokenOneOf$vtype;

// Constructors
extern void _jc_gnu_regexp_RETokenOneOf$method$_init$ed847b5491a86199(_jc_env *, struct _jc_gnu_regexp_RETokenOneOf$object *, jint, struct _jc_java_lang_String$object *, jboolean, jboolean);
extern void _jc_gnu_regexp_RETokenOneOf$method$_init$e815476efe6b3b9b(_jc_env *, struct _jc_gnu_regexp_RETokenOneOf$object *, jint, struct _jc_java_util_Vector$object *, jboolean);

// Virtual methods
extern void _jc_gnu_regexp_RETokenOneOf$method$dump$9e5199210196a89c(_jc_env *, struct _jc_gnu_regexp_RETokenOneOf$object *, struct _jc_java_lang_StringBuffer$object *);
extern jint _jc_gnu_regexp_RETokenOneOf$method$getMinimumLength$13aeed906e65d975(_jc_env *, struct _jc_gnu_regexp_RETokenOneOf$object *);
extern jboolean _jc_gnu_regexp_RETokenOneOf$method$match$d139de67a06a4f32(_jc_env *, struct _jc_gnu_regexp_RETokenOneOf$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_RETokenOneOf$method_info$dump$9e5199210196a89c;
extern _jc_method _jc_gnu_regexp_RETokenOneOf$method_info$getMinimumLength$13aeed906e65d975;
extern _jc_method _jc_gnu_regexp_RETokenOneOf$method_info$match$d139de67a06a4f32;

// Virtual methods structure
struct _jc_gnu_regexp_RETokenOneOf$vmethods {
	void	(*dump$9e5199210196a89c)(_jc_env *, struct _jc_gnu_regexp_RETokenOneOf$object *, struct _jc_java_lang_StringBuffer$object *);
	jint	(*getMinimumLength$13aeed906e65d975)(_jc_env *, struct _jc_gnu_regexp_RETokenOneOf$object *);
	jboolean	(*match$d139de67a06a4f32)(_jc_env *, struct _jc_gnu_regexp_RETokenOneOf$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *);
};

// Vtable
struct _jc_gnu_regexp_RETokenOneOf$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_REToken$vmethods	gnu_regexp_REToken;
	_jc_gnu_regexp_RETokenOneOf$vmethods	gnu_regexp_RETokenOneOf;
};

// Vtype
struct _jc_gnu_regexp_RETokenOneOf$vtype {
	_jc_type			type;
	_jc_gnu_regexp_RETokenOneOf$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenOneOf$sub_refs {
	struct _jc_java_util_Vector$object	*options;
};

// Reference instance fields (object)
struct _jc_gnu_regexp_RETokenOneOf$refs {
    _jc_gnu_regexp_RETokenOneOf$sub_refs	gnu_regexp_RETokenOneOf;
    _jc_gnu_regexp_REToken$sub_refs	gnu_regexp_REToken;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenOneOf$sub_nonrefs {
	jboolean	negative;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_RETokenOneOf$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_REToken$sub_nonrefs	gnu_regexp_REToken;
    _jc_gnu_regexp_RETokenOneOf$sub_nonrefs	gnu_regexp_RETokenOneOf;
};

// Object instance structure
struct _jc_gnu_regexp_RETokenOneOf$object {
	_jc_gnu_regexp_RETokenOneOf$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_RETokenOneOf$vtype	*vtype;
	_jc_gnu_regexp_RETokenOneOf$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_RETokenOneOf$vtype _jc_gnu_regexp_RETokenOneOf$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_RETokenOneOf, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_RETokenOneOf$class_object;

#endif	/* _JC_gnu_regexp_RETokenOneOf_H_ */

==> jc-1.4.6.tar.gz: gnu/regexp/RETokenOneOf.h <==
// final class gnu.regexp.RETokenOneOf

// class file dependencies
// @dep_class 3c97b6b42ac22db4 gnu_regexp_REToken
// @dep_class d6d93778273344e gnu_regexp_RETokenOneOf
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_regexp_REToken

#include "gnu/regexp/REToken.h"

#ifndef _JC_gnu_regexp_RETokenOneOf_H_
#define _JC_gnu_regexp_RETokenOneOf_H_

// Forward structure declarations
struct _jc_gnu_regexp_CharIndexed$object;
struct _jc_gnu_regexp_REMatch$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_StringBuffer$object;
struct _jc_java_util_Vector$object;

// Typedefs
typedef struct _jc_gnu_regexp_RETokenOneOf$sub_refs	_jc_gnu_regexp_RETokenOneOf$sub_refs;
typedef struct _jc_gnu_regexp_RETokenOneOf$sub_nonrefs	_jc_gnu_regexp_RETokenOneOf$sub_nonrefs;
typedef struct _jc_gnu_regexp_RETokenOneOf$refs	_jc_gnu_regexp_RETokenOneOf$refs;
typedef struct _jc_gnu_regexp_RETokenOneOf$nonrefs	_jc_gnu_regexp_RETokenOneOf$nonrefs;
typedef struct _jc_gnu_regexp_RETokenOneOf$object	_jc_gnu_regexp_RETokenOneOf$object;

typedef const struct _jc_gnu_regexp_RETokenOneOf$vmethods	_jc_gnu_regexp_RETokenOneOf$vmethods;
typedef const struct _jc_gnu_regexp_RETokenOneOf$vtable	_jc_gnu_regexp_RETokenOneOf$vtable;
typedef const struct _jc_gnu_regexp_RETokenOneOf$vtype	_jc_gnu_regexp_RETokenOneOf$vtype;

// Constructors
extern void _jc_gnu_regexp_RETokenOneOf$method$_init$ed847b5491a86199(_jc_env *, struct _jc_gnu_regexp_RETokenOneOf$object *, jint, struct _jc_java_lang_String$object *, jboolean, jboolean) _JC_JCNI_ATTR;
extern void _jc_gnu_regexp_RETokenOneOf$method$_init$e815476efe6b3b9b(_jc_env *, struct _jc_gnu_regexp_RETokenOneOf$object *, jint, struct _jc_java_util_Vector$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_regexp_RETokenOneOf$method$dump$9e5199210196a89c(_jc_env *, struct _jc_gnu_regexp_RETokenOneOf$object *, struct _jc_java_lang_StringBuffer$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_regexp_RETokenOneOf$method$getMinimumLength$13aeed906e65d975(_jc_env *, struct _jc_gnu_regexp_RETokenOneOf$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_regexp_RETokenOneOf$method$match$d139de67a06a4f32(_jc_env *, struct _jc_gnu_regexp_RETokenOneOf$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_RETokenOneOf$method_info$dump$9e5199210196a89c;
extern _jc_method _jc_gnu_regexp_RETokenOneOf$method_info$getMinimumLength$13aeed906e65d975;
extern _jc_method _jc_gnu_regexp_RETokenOneOf$method_info$match$d139de67a06a4f32;

// Virtual methods structure
struct _jc_gnu_regexp_RETokenOneOf$vmethods {
	void	(*dump$9e5199210196a89c)(_jc_env *, struct _jc_gnu_regexp_RETokenOneOf$object *, struct _jc_java_lang_StringBuffer$object *) _JC_JCNI_ATTR;
	jint	(*getMinimumLength$13aeed906e65d975)(_jc_env *, struct _jc_gnu_regexp_RETokenOneOf$object *) _JC_JCNI_ATTR;
	jboolean	(*match$d139de67a06a4f32)(_jc_env *, struct _jc_gnu_regexp_RETokenOneOf$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_regexp_RETokenOneOf$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_REToken$vmethods	gnu_regexp_REToken;
	_jc_gnu_regexp_RETokenOneOf$vmethods	gnu_regexp_RETokenOneOf;
};

// Vtype
struct _jc_gnu_regexp_RETokenOneOf$vtype {
	_jc_type			type;
	_jc_gnu_regexp_RETokenOneOf$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenOneOf$sub_refs {
	struct _jc_java_util_Vector$object	*options;
};

// Reference instance fields (object)
struct _jc_gnu_regexp_RETokenOneOf$refs {
    _jc_gnu_regexp_RETokenOneOf$sub_refs	gnu_regexp_RETokenOneOf;
    _jc_gnu_regexp_REToken$sub_refs	gnu_regexp_REToken;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenOneOf$sub_nonrefs {
	jboolean	negative;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_RETokenOneOf$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_REToken$sub_nonrefs	gnu_regexp_REToken;
    _jc_gnu_regexp_RETokenOneOf$sub_nonrefs	gnu_regexp_RETokenOneOf;
};

// Object instance structure
struct _jc_gnu_regexp_RETokenOneOf$object {
	_jc_gnu_regexp_RETokenOneOf$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_RETokenOneOf$vtype	*vtype;
	_jc_gnu_regexp_RETokenOneOf$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_RETokenOneOf$vtype _jc_gnu_regexp_RETokenOneOf$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_RETokenOneOf, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_RETokenOneOf$class_object;

#endif	/* _JC_gnu_regexp_RETokenOneOf_H_ */
